# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import enum

import winrt.system
from winrt import _winrt_windows_foundation_diagnostics

__all__ = [
    "CausalityRelation",
    "CausalitySource",
    "CausalitySynchronousWork",
    "CausalityTraceLevel",
    "ErrorOptions",
    "LoggingFieldFormat",
    "LoggingLevel",
    "LoggingOpcode",
    "AsyncCausalityTracer",
    "ErrorDetails",
    "FileLoggingSession",
    "LogFileGeneratedEventArgs",
    "LoggingActivity",
    "LoggingChannel",
    "LoggingChannelOptions",
    "LoggingFields",
    "LoggingOptions",
    "LoggingSession",
    "RuntimeBrokerErrorSettings",
    "TracingStatusChangedEventArgs",
    "IErrorReportingSettings",
    "IFileLoggingSession",
    "ILoggingChannel",
    "ILoggingSession",
    "ILoggingTarget",
]

class CausalityRelation(enum.IntEnum):
    ASSIGN_DELEGATE = 0
    JOIN = 1
    CHOICE = 2
    CANCEL = 3
    ERROR = 4

class CausalitySource(enum.IntEnum):
    APPLICATION = 0
    LIBRARY = 1
    SYSTEM = 2

class CausalitySynchronousWork(enum.IntEnum):
    COMPLETION_NOTIFICATION = 0
    PROGRESS_NOTIFICATION = 1
    EXECUTION = 2

class CausalityTraceLevel(enum.IntEnum):
    REQUIRED = 0
    IMPORTANT = 1
    VERBOSE = 2

class ErrorOptions(enum.IntFlag):
    NONE = 0x0
    SUPPRESS_EXCEPTIONS = 0x1
    FORCE_EXCEPTIONS = 0x2
    USE_SET_ERROR_INFO = 0x4
    SUPPRESS_SET_ERROR_INFO = 0x8

class LoggingFieldFormat(enum.IntEnum):
    DEFAULT = 0
    HIDDEN = 1
    STRING = 2
    BOOLEAN = 3
    HEXADECIMAL = 4
    PROCESS_ID = 5
    THREAD_ID = 6
    PORT = 7
    IPV4_ADDRESS = 8
    IPV6_ADDRESS = 9
    SOCKET_ADDRESS = 10
    XML = 11
    JSON = 12
    WIN32_ERROR = 13
    N_T_STATUS = 14
    H_RESULT = 15
    FILE_TIME = 16
    SIGNED = 17
    UNSIGNED = 18

class LoggingLevel(enum.IntEnum):
    VERBOSE = 0
    INFORMATION = 1
    WARNING = 2
    ERROR = 3
    CRITICAL = 4

class LoggingOpcode(enum.IntEnum):
    INFO = 0
    START = 1
    STOP = 2
    REPLY = 6
    RESUME = 7
    SUSPEND = 8
    SEND = 9

AsyncCausalityTracer = _winrt_windows_foundation_diagnostics.AsyncCausalityTracer
ErrorDetails = _winrt_windows_foundation_diagnostics.ErrorDetails
FileLoggingSession = _winrt_windows_foundation_diagnostics.FileLoggingSession
LogFileGeneratedEventArgs = _winrt_windows_foundation_diagnostics.LogFileGeneratedEventArgs
LoggingActivity = _winrt_windows_foundation_diagnostics.LoggingActivity
LoggingChannel = _winrt_windows_foundation_diagnostics.LoggingChannel
LoggingChannelOptions = _winrt_windows_foundation_diagnostics.LoggingChannelOptions
LoggingFields = _winrt_windows_foundation_diagnostics.LoggingFields
LoggingOptions = _winrt_windows_foundation_diagnostics.LoggingOptions
LoggingSession = _winrt_windows_foundation_diagnostics.LoggingSession
RuntimeBrokerErrorSettings = _winrt_windows_foundation_diagnostics.RuntimeBrokerErrorSettings
TracingStatusChangedEventArgs = _winrt_windows_foundation_diagnostics.TracingStatusChangedEventArgs
IErrorReportingSettings = _winrt_windows_foundation_diagnostics.IErrorReportingSettings
IFileLoggingSession = _winrt_windows_foundation_diagnostics.IFileLoggingSession
ILoggingChannel = _winrt_windows_foundation_diagnostics.ILoggingChannel
ILoggingSession = _winrt_windows_foundation_diagnostics.ILoggingSession
ILoggingTarget = _winrt_windows_foundation_diagnostics.ILoggingTarget
